@@ -53,6 +53,8 @@ class DiscordInteractionsBlueprint:
         annotations=None,
         type=ApplicationCommandType.CHAT_INPUT,
         default_permission=None,
+        default_member_permissions=None,
+        dm_permission=None,
         permissions=None,
     ):
         """
@@ -75,7 +77,11 @@ class DiscordInteractionsBlueprint:
         type
             The ``ApplicationCommandType`` of the command.
         default_permission
-            Whether the command is enabled by default. Default is True.
+            Deprecated as of v1.5! Whether the command is enabled by default.
+        default_member_permissions
+            A permission integer defining the required permissions a user must have to run the command
+        dm_permission
+            Indicates whether the command can be used in DMs
         permissions
             List of permission overwrites.
         """
@@ -87,6 +93,8 @@ class DiscordInteractionsBlueprint:
             annotations,
             type,
             default_permission,
+            default_member_permissions,
+            dm_permission,
             permissions,
             self,
         )
@@ -114,6 +122,8 @@ class DiscordInteractionsBlueprint:
         annotations=None,
         type=ApplicationCommandType.CHAT_INPUT,
         default_permission=None,
+        default_member_permissions=None,
+        dm_permission=None,
         permissions=None,
     ):
         """
@@ -134,7 +144,11 @@ class DiscordInteractionsBlueprint:
         type
             The ``ApplicationCommandType`` of the command.
         default_permission
-            Whether the command is enabled by default. Default is True.
+            Deprecated as of v1.5! Whether the command is enabled by default.
+        default_member_permissions
+            A permission integer defining the required permissions a user must have to run the command
+        dm_permission
+            Indicates whether the command can be used in DMs
         permissions
             List of permission overwrites.
         """
@@ -149,6 +163,8 @@ class DiscordInteractionsBlueprint:
                 annotations,
                 type,
                 default_permission,
+                default_member_permissions,
+                dm_permission,
                 permissions,
             )
             return command
@@ -161,6 +177,8 @@ class DiscordInteractionsBlueprint:
         description="No description",
         is_async=False,
         default_permission=None,
+        default_member_permissions=None,
+        dm_permission=None,
         permissions=None,
     ):
         """
@@ -177,13 +195,23 @@ class DiscordInteractionsBlueprint:
             Whether the subgroup should be considered async (if subcommands
             get an :class:`.AsyncContext` instead of a :class:`Context`.)
         default_permission
-            Whether the command group is enabled by default.
+            Deprecated as of v1.5! Whether the command is enabled by default.
+        default_member_permissions
+            A permission integer defining the required permissions a user must have to run the command
+        dm_permission
+            Indicates whether the command canbe used in DMs
         permissions
             List of permission overwrites. These apply to the entire group.
         """
 
         group = SlashCommandGroup(
-            name, description, is_async, default_permission, permissions
+            name,
+            description,
+            is_async,
+            default_permission,
+            default_member_permissions,
+            dm_permission,
+            permissions,
         )
         self.discord_commands[name] = group
         return group
@@ -297,7 +325,7 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
         if app.config["DONT_REGISTER_WITH_DISCORD"]:
             app.discord_token = {
                 "token_type": "Bearer",
-                "scope": "applications.commands.update",
+                "scope": "applications.commands.update applications.commands.permissions.update",
                 "expires_in": 604800,
                 "access_token": "DONT_REGISTER_WITH_DISCORD",
             }
@@ -309,7 +337,7 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
             app.config["DISCORD_BASE_URL"] + "/oauth2/token",
             data={
                 "grant_type": "client_credentials",
-                "scope": "applications.commands.update",
+                "scope": "applications.commands.update applications.commands.permissions.update",
             },
             headers={"Content-Type": "application/x-www-form-urlencoded"},
             auth=(app.config["DISCORD_CLIENT_ID"], app.config["DISCORD_CLIENT_SECRET"]),
@@ -393,30 +421,22 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
             for command in app.discord_commands.values():
                 command.id = command.name
 
-        url += "/permissions"
-
-        permissions_data = [
-            {"id": command.id, "permissions": command.dump_permissions()}
-            for command in app.discord_commands.values()
-            if command.permissions
-        ]
-
-        if not permissions_data:
-            return
-
-        if not app.config["DONT_REGISTER_WITH_DISCORD"]:
-            response = requests.put(
-                url, json=permissions_data, headers=self.auth_headers(app)
-            )
-            self.throttle(response)
-
-            try:
-                response.raise_for_status()
-            except requests.exceptions.HTTPError:
-                raise ValueError(
-                    f"Unable to register permissions:"
-                    f"{response.status_code} {response.text}"
+        for command in app.discord_commands.values():
+            if not app.config["DONT_REGISTER_WITH_DISCORD"]:
+                response = requests.put(
+                    url + "/" + command.id + "/permissions",
+                    json={"permissions": command.dump_permissions()},
+                    headers=self.auth_headers(app),
                 )
+                self.throttle(response)
+
+                try:
+                    response.raise_for_status()
+                except requests.exceptions.HTTPError:
+                    raise ValueError(
+                        f"Unable to register permissions for {command.id}:"
+                        f"{response.status_code} {response.text}"
+                    )
 
     def update_slash_commands(self, *args, **kwargs):
         """
@@ -603,7 +623,9 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
                 return jsonify(self.run_autocomplete(request.json).dump())
 
             elif interaction_type == InteractionType.MODAL_SUBMIT:
-                return jsonify(self.run_handler(request.json, allow_modal=False).dump_handler())
+                return jsonify(
+                    self.run_handler(request.json, allow_modal=False).dump_handler()
+                )
 
             else:
                 raise RuntimeWarning(
